@@ -1,10 +1,10 @@
 ;;; meow-tree-sitter.el --- Tree-sitter powered motions for Meow -*- lexical-binding: t -*-
 
-;; Copyright (C) 2024 Ad
+;; Copyright (C) 2025 Ad
 
 ;; Author: Ad <me@skissue.xyz>
-;; Package-Version: 20251025.333
-;; Package-Revision: af705960ea34
+;; Package-Version: 20251118.1939
+;; Package-Revision: ef69efbbc5a7
 ;; Package-Requires: ((emacs "29.1") (meow "1.2.0"))
 ;; URL: https://github.com/skissue/meow-tree-sitter
 ;; Keywords: convenience, files, languages, tools
@@ -297,6 +297,39 @@ binds!"
                                                   meow-char-thing-table))
     (meow-tree-sitter-register-thing (car bind) (cdr bind))))
 
+;;;###autoload
+(defun meow-tree-sitter-node ()
+  "Tree-sitter version of `meow-block'.
+Will automatically fall back to `meow-block' if no treesit parser is
+available."
+  (interactive)
+  (let ((p (point))
+        (m (mark))
+        (node (treesit-node-at (point))))
+    (if (null node)
+        ;; No tree-sitter data available.
+        (call-interactively #'meow-block)
+      ;; If the region is active, expand the node until it contains both point
+      ;; and mark. "Contain" requires that the node not be at the boundaries,
+      ;; which is how consistent expansion is guaranteed.
+      ;;
+      ;; NOTE: this is a bit hacky and inconsistent, might be better to refactor
+      ;; in the future.
+      (when (region-active-p)
+        (setq node (treesit-parent-until
+                    node (lambda (n)
+                           (or (< (treesit-node-start n)
+                                  p
+                                  (treesit-node-end n))
+                               (< (treesit-node-start n)
+                                  m
+                                  (treesit-node-end n)))))))
+      (thread-first
+        (meow--make-selection '(expand . block)
+                              (treesit-node-start node)
+                              (treesit-node-end node))
+        (meow--select t)))))
+
 (provide 'meow-tree-sitter)
 
 ;;; meow-tree-sitter.el ends here
